import asyncio
import random

from pyrogram.types import Message
from pyrogram.raw.functions.messages import RequestWebView

from .future import FutureCheckin


__ignore__ = True


class TestFutureCheckin(FutureCheckin):
    name = "未响签到测试"

    click_button = ["注册", "註冊"]



from .pandatv_group import PandaTVGroupCheckin

__ignore__ = True


class TestPandaTVGroupCheckin(PandaTVGroupCheckin):
    name = "PandaTV 群组签到测试"
    chat_name = "api_group"

    async def send_checkin(self, retry=False):
        await super().send_checkin(retry=retry)
        self.finished.set()
